==> react-atom-skeleton-1.0.2.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import React from 'react';
import cx from 'classnames';
export var ATOM_SKELETON_ANIMATIONS = {
  wave: 'wave',
  pulse: 'pulse'
};
export var ATOM_SKELETON_VARIANTS = {
  round: 'round',
  circle: 'circle',
  square: 'square'
};
export default function AtomSkeleton(_ref) {
  var _cx;

  var _ref$count = _ref.count,
      count = _ref$count === void 0 ? 1 : _ref$count,
      _ref$variant = _ref.variant,
      variant = _ref$variant === void 0 ? ATOM_SKELETON_VARIANTS.round : _ref$variant,
      _ref$animation = _ref.animation,
      animation = _ref$animation === void 0 ? ATOM_SKELETON_ANIMATIONS.pulse : _ref$animation,
      style = _ref.style,
      width = _ref.width,
      height = _ref.height,
      others = _objectWithoutPropertiesLoose(_ref, ["count", "variant", "animation", "style", "width", "height"]);

  var baseClass = 'react-AtomSkeleton';
  var className = cx("" + baseClass, (_cx = {}, _cx[baseClass + "--pulse"] = animation === ATOM_SKELETON_ANIMATIONS.pulse, _cx[baseClass + "--wave"] = animation === ATOM_SKELETON_ANIMATIONS.wave, _cx[baseClass + "--round"] = variant === ATOM_SKELETON_VARIANTS.round, _cx[baseClass + "--circle"] = variant === ATOM_SKELETON_VARIANTS.circle, _cx));
  return /*#__PURE__*/React.createElement(React.Fragment, null, Array.from(Array(count).keys()).map(function (index) {
    return /*#__PURE__*/React.createElement("span", Object.assign({
      key: index,
      className: className,
      style: _extends({}, style, {
        width: width,
        height: height
      })
    }, others), "\u200C");
  }));
}
AtomSkeleton.displayName = 'AtomSkeleton';

==> react-atom-skeleton-1.2.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import cx from 'classnames';
export var ATOM_SKELETON_ANIMATIONS = {
  wave: 'wave',
  pulse: 'pulse'
};
export var ATOM_SKELETON_VARIANTS = {
  round: 'round',
  circle: 'circle',
  square: 'square'
};
export default function AtomSkeleton(_ref) {
  var _cx;

  var _ref$count = _ref.count,
      count = _ref$count === void 0 ? 1 : _ref$count,
      _ref$variant = _ref.variant,
      variant = _ref$variant === void 0 ? ATOM_SKELETON_VARIANTS.round : _ref$variant,
      _ref$animation = _ref.animation,
      animation = _ref$animation === void 0 ? ATOM_SKELETON_ANIMATIONS.pulse : _ref$animation,
      style = _ref.style,
      width = _ref.width,
      height = _ref.height,
      others = _objectWithoutPropertiesLoose(_ref, ["count", "variant", "animation", "style", "width", "height"]);

  var baseClass = 'react-AtomSkeleton';
  var className = cx("" + baseClass, (_cx = {}, _cx[baseClass + "--pulse"] = animation === ATOM_SKELETON_ANIMATIONS.pulse, _cx[baseClass + "--wave"] = animation === ATOM_SKELETON_ANIMATIONS.wave, _cx[baseClass + "--round"] = variant === ATOM_SKELETON_VARIANTS.round, _cx[baseClass + "--circle"] = variant === ATOM_SKELETON_VARIANTS.circle, _cx));
  return /*#__PURE__*/_jsx(_Fragment, {
    children: Array.from(Array(count).keys()).map(function (index) {
      return /*#__PURE__*/_jsx("span", _extends({
        className: className,
        style: _extends({}, style, {
          width: width,
          height: height
        })
      }, others, {
        children: "\u200C"
      }), index);
    })
  });
}
AtomSkeleton.displayName = 'AtomSkeleton';
